package com.eden.room.common.enums;

/**
 * 房源类型枚举
 */
public enum RoomTypeEnum {
    
    /** 办公 */
    OFFICE("1","办公"),
    
    /** 商业 */
    BUSINESS("2","商业"),
    
    /** 仓储 */
    STORAGE("3","仓储"),
    
    /** 厂房 */
    FACTORY("4","厂房"),
    
    /** 多经 */
    MULTI_ECONOMIC("5","多经"),
    
    /** 公寓 */
    APARTMENT("6","公寓"),
    
    /** 住宅 */
    RESIDENTIAL("7","住宅"),
    
    /** 其他 */
    OTHER("8","其他");


    private final String key;

    private final String value;

    public String getKey() {
        return key;
    }

    public String getValue() {
        return value;
    }

    RoomTypeEnum(String key, String value) {
        this.value = value;
        this.key = key;
    }

    /**
     * 根据值获取枚举
     *
     * @param value 枚举值
     * @return 枚举
     */
    public static String getByValue(String value) {
        for (RoomTypeEnum status : values()) {
            if (status.getValue().equals(value)) {
                return status.getKey();
            }
        }
        return null;
    }
    /**
     * 根据枚举获取值
     *
     * @param key
     * @return 枚举
     */
    public static String getValue(String key) {
        for (RoomTypeEnum status : values()) {
            if (status.getKey().equals(key)) {
                return status.getValue();
            }
        }
        return null;
    }
    /**
     * 校验枚举值是否有效
     *
     * @param key 枚举值
     * @return 是否有效
     */
    public static boolean isValid(String key) {
        for (RoomTypeEnum status : values()) {
            if (status.getKey().equals(key)) {
                return true;
            }
        }
        return false;
    }
} 