package com.eden.room.controller;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.eden.common.core.controller.BaseController;
import com.eden.room.common.Result;
import com.eden.room.domain.Floor;
import com.eden.room.service.IFloorService;

/**
 * 楼层信息Controller
 */
@RestController
@RequestMapping("/room/floor")
public class FloorController extends BaseController {
    @Autowired
    private IFloorService floorService;

    /**
     * 查询楼层信息列表
     */
    @GetMapping("/list")
    public Result<PageInfo<Floor>> list(Floor floor, 
                                      @RequestParam(defaultValue = "1") Integer pageNum,
                                      @RequestParam(defaultValue = "10") Integer pageSize) {
        startPage(pageNum, pageSize);
        List<Floor> list = floorService.selectFloorList(floor);
        return getPageResult(list);
    }

    /**
     * 获取楼层信息详细信息
     */
    @GetMapping(value = "/{id}")
    public Result<Floor> getInfo(@PathVariable("id") Long id) {
        return success(floorService.selectFloorById(id));
    }

    /**
     * 新增楼层信息
     */
    @PostMapping("/add")
    public Result<Integer> add(@RequestBody Floor floor) {
        int rows = floorService.insertFloor(floor);
        return toResult(rows);
    }

    /**
     * 修改楼层信息
     */
    @PostMapping("/edit")
    public Result<Integer> edit(@RequestBody Floor floor) {
        int rows = floorService.updateFloor(floor);
        return toResult(rows);
    }

    /**
     * 删除楼层信息
     */
    @PostMapping("/remove/{ids}")
    public Result<Integer> remove(@PathVariable List<Long> ids) {
        int rows = floorService.deleteFloorByIds(ids);
        return toResult(rows);
    }

    /**
     * 根据楼宇ID查询楼层列表
     */
    @GetMapping("/building/{buildingId}")
    public Result<List<Floor>> getFloorsByBuilding(@PathVariable("buildingId") Long buildingId) {
        List<Floor> list = floorService.selectFloorListByBuildingId(buildingId);
        return success(list);
    }
} 