package com.eden.room.domain.dto;

import com.eden.room.common.enums.BusinessStatusEnum;
import com.eden.room.common.enums.DecorationStatusEnum;
import com.eden.room.common.enums.PropertyNatureEnum;
import com.eden.room.common.enums.RentalStatusEnum;
import com.eden.room.common.enums.RoomStatusEnum;
import com.eden.room.common.enums.RoomTypeEnum;
import com.eden.room.domain.Room;
import com.eden.room.domain.RoomBusinessInfo;
import com.eden.room.domain.RoomExtendInfo;
import com.eden.room.domain.RoomImage;
import com.eden.room.utils.EnumValid;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.List;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

/**
 * 房源信息DTO，包含基础信息、招商信息和拓展信息
 */
@Data
@EqualsAndHashCode(callSuper = true)
public class RoomDTO extends Room {
    
    private static final long serialVersionUID = 1L;
    
    /** 招商信息 */
    @Valid
    private RoomBusinessInfo businessInfo;
    
    /** 拓展信息 */
    private RoomExtendInfo extendInfo;
    
    /** 房源图片列表 */
    private List<RoomImage> roomImages;
    
    /** 户型图列表 */
    private List<RoomImage> floorPlanImages;
    
    /** 项目名称 */
    private String projectName;
    
    /** 楼宇名称 */
    private String buildingName;
    
    /** 楼层名称 */
    private String floorName;
    
    /** 业主名称 */
    private String ownerName;
    
    /** 标签列表 */
    private String tags;

    @EnumValid(value = RoomTypeEnum.class, message = "无效的房源类型")
    private String roomType;

    @EnumValid(value = RoomStatusEnum.class, message = "无效的房源状态")
    private String roomStatus;

    @EnumValid(value = PropertyNatureEnum.class, message = "无效的产权性质")
    private String propertyNature;

    public RoomBusinessInfo getBusinessInfo() {
        return businessInfo;
    }

    public void setBusinessInfo(RoomBusinessInfo businessInfo) {
        this.businessInfo = businessInfo;
    }

    public RoomExtendInfo getExtendInfo() {
        return extendInfo;
    }

    public void setExtendInfo(RoomExtendInfo extendInfo) {
        this.extendInfo = extendInfo;
    }

    public List<RoomImage> getRoomImages() {
        return roomImages;
    }

    public void setRoomImages(List<RoomImage> roomImages) {
        this.roomImages = roomImages;
    }

    public List<RoomImage> getFloorPlanImages() {
        return floorPlanImages;
    }

    public void setFloorPlanImages(List<RoomImage> floorPlanImages) {
        this.floorPlanImages = floorPlanImages;
    }

    @Override
    public String getProjectName() {
        return projectName;
    }

    @Override
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    @Override
    public String getBuildingName() {
        return buildingName;
    }

    @Override
    public void setBuildingName(String buildingName) {
        this.buildingName = buildingName;
    }

    @Override
    public String getFloorName() {
        return floorName;
    }

    @Override
    public void setFloorName(String floorName) {
        this.floorName = floorName;
    }

    public String getOwnerName() {
        return ownerName;
    }

    public void setOwnerName(String ownerName) {
        this.ownerName = ownerName;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }
}