package com.eden.room.domain.dto;

import java.math.BigDecimal;
import java.util.Date;

import com.eden.room.common.enums.*;
import com.eden.room.utils.EnumConvert;
import com.eden.room.utils.excel.Excel;
import lombok.Data;

/**
 * 房源导出数据传输对象
 */
@Data
public class RoomExportDTO {

    /**
     * 项目名称
     */
    @Excel(name = "项目名称", required = true, sort = 1)
    private String projectName;

    /**
     * 楼宇名称
     */
    @Excel(name = "楼宇名称", required = true, sort = 2)
    private String buildingName;

    /**
     * 楼层
     */
    @Excel(name = "楼层", required = true, sort = 3)
    private String floorName;

    /**
     * 房源编号
     */
    @Excel(name = "房号", required = true, sort = 4)
    private String roomNumber;
    /**
     * 计租面积
     */
    @Excel(name = "计租面积", required = true, sort = 5)
    private BigDecimal rentalArea;

    /**
     * 报价+单位
     */
    @Excel(name = "报价", required = true, sort = 6)
    private String priceAndUnit;

    /**
     * 租赁状态
     */
    @Excel(name = "租赁状态", required = true, sort = 7)
    @EnumConvert(RentalStatusEnum.class)
    private String rentalStatus;

    /**
     * 可租日期
     */
    @Excel(name = "可租日期", required = true, sort = 8)
    private Date availableDate;
    /**
     * 房源标签
     */
    @Excel(name = "房源标签", required = true, sort = 9)
    private String tags;
    /**
     * 虚拟房源
     */
    @Excel(name = "虚拟房源", sort =10)
    @EnumConvert(VirtualFlagEnum.class)
    private String isVirtual;

    /**
     * 招商状态
     */
    @Excel(name = "招商状态", sort = 11)
    @EnumConvert(BusinessStatusEnum.class)
    private String businessStatus;

    /**
     * 装修情况
     */
    @Excel(name = "装修情况", sort = 12)
    @EnumConvert(DecorationStatusEnum.class)
    private String decorationStatus;

    /**
     * 房源交付时间
     */
    @Excel(name = "房源交付时间", sort = 13)
    private Date deliveryTime;
    /**
     * 创建时间
     */
    @Excel(name = "创建时间", sort = 14)
    private Date createTime;


    /**
     * 房源类型
     * 使用EnumConverter将枚举类型的key转换为对应的value
     */
    @Excel(name = "房源类型", sort = 15)
    @EnumConvert(RoomTypeEnum.class)
    private String roomType;
    
    /**
     * 房源ID
     */
    private Long id;
    
    /**
     * 项目ID
     */
    private String projectId;

    
    /**
     * 楼宇ID
     */
    private Long buildingId;

    
    /**
     * 楼层ID
     */
    private Long floorId;
    
    /**
     * 房源数字编号
     */
    private String roomDigitalNumber;
    
    /**
     * 房源管理编号
     */
    private String roomManageNumber;
    
    /**
     * 房源名称
     */
    private String roomName;
    /**
     * 楼层
     */
    private String floor;

    /**
     * 建筑面积
     */
    private BigDecimal buildingArea;

    
    /**
     * 计费面积
     */
    private BigDecimal billingArea;
    
    /**
     * 套内面积
     */
    private BigDecimal innerArea;
    
    /**
     * 绑定业主ID
     */
    private Long ownerId;
    
    /**
     * 业主名称
     */
    private String ownerName;
    
    /**
     * 业主电话
     */
    private String ownerPhone;
    
    /**
     * 产权性质
     */
    private String propertyNature;
    
    /**
     * 层高(米)
     */
    private BigDecimal height;
    
    /**
     * 荷载值
     */
    private BigDecimal loadValue;
    
    /**
     * 房源状态
     */
    private String roomStatus;
    
    /**
     * 价格
     */
    private String price;
    
    /**
     * 价格单位
     */
    private String priceUnit;
}