package com.eden.room.mapper;

import java.util.List;
import java.util.Set;
import com.eden.room.domain.Floor;
import org.apache.ibatis.annotations.Param;

/**
 * 楼层信息数据访问层
 */
public interface FloorMapper {
    /**
     * 查询楼层信息列表
     * 
     * @param floor 楼层信息查询条件
     * @return 楼层信息集合
     */
    List<Floor> selectFloorList(Floor floor);
    
    /**
     * 根据楼层ID查询楼层信息
     * 
     * @param id 楼层ID
     * @return 楼层信息
     */
    Floor selectFloorById(Long id);
    
    /**
     * 新增楼层信息
     * 
     * @param floor 楼层信息
     * @return 结果
     */
    int insertFloor(Floor floor);
    
    /**
     * 修改楼层信息
     * 
     * @param floor 楼层信息
     * @return 结果
     */
    int updateFloor(Floor floor);
    
    /**
     * 批量删除楼层信息
     * 
     * @param ids 需要删除的楼层ID数组
     * @return 结果
     */
    int deleteFloorByIds(List<Long> ids);
    
    /**
     * 删除楼层信息
     * 
     * @param id 楼层ID
     * @return 结果
     */
    int deleteFloorById(Long id);
    
    /**
     * 检查楼层名称是否已存在
     * 
     * @param floor 楼层信息
     * @return 结果
     */
    int checkFloorNameExists(Floor floor);
    
    /**
     * 检查楼层数字编号是否已存在
     * 
     * @param floor 楼层信息
     * @return 结果
     */
    int checkFloorNumberExists(Floor floor);
    
    /**
     * 楼层统计信息
     * 
     * @param id 楼层ID
     * @return 楼层信息
     */
    Floor selectFloorStatistics(Long id);
    
    /**
     * 根据楼层名称和楼宇ID查询楼层ID
     * 
     * @param floorName 楼层名称
     * @param buildingId 楼宇ID
     * @return 楼层ID
     */
    String selectFloorIdByNameAndBuildingId(String floorName, Long buildingId);
    
    /**
     * 检查楼层是否有房源
     * 
     * @param id 楼层ID
     * @return 结果
     */
    int checkFloorHasRooms(Long id);
    
    /**
     * 根据楼栋ID和楼层名称列表查询楼层列表
     * 
     * @param buildingId 楼栋ID
     * @param floorNames 楼层名称列表
     * @return 楼层列表
     */
    List<Floor> selectFloorListByNames(@Param("buildingId") Long buildingId, @Param("floorNames") Set<String> floorNames);
} 