package com.eden.room.mapper;

import com.eden.room.domain.RoomBusinessInfo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 房源招商信息数据访问层
 */
@Mapper
public interface RoomBusinessInfoMapper {
    
    /**
     * 查询房源招商信息列表
     *
     * @param businessInfo 房源招商信息
     * @return 房源招商信息列表
     */
    List<RoomBusinessInfo> selectRoomBusinessInfoList(RoomBusinessInfo businessInfo);
    
    /**
     * 根据ID查询房源招商信息
     *
     * @param id 招商信息ID
     * @return 房源招商信息
     */
    RoomBusinessInfo selectRoomBusinessInfoById(@Param("id") String id);
    
    /**
     * 根据房源ID查询招商信息
     *
     * @param roomId 房源ID
     * @return 房源招商信息
     */
    RoomBusinessInfo selectRoomBusinessInfoByRoomId(@Param("roomId") Long roomId);

    /**
     * 批量插入房源招商信息
     *
     * @param businessInfos 房源招商信息列表
     * @return 插入结果
     */
    int batchInsertBusinessInfos(@Param("list") List<RoomBusinessInfo> businessInfos);
    
    /**
     * 修改房源招商信息
     *
     * @param businessInfo 房源招商信息
     * @return 结果
     */
    int updateRoomBusinessInfo(RoomBusinessInfo businessInfo);
    
    /**
     * 删除房源招商信息
     *
     * @param id 招商信息ID
     * @return 结果
     */
    int deleteRoomBusinessInfoById(@Param("id") String id);
    
    /**
     * 根据房源ID删除招商信息
     *
     * @param roomId 房源ID
     * @return 结果
     */
    int deleteRoomBusinessInfoByRoomId(@Param("roomId") Long roomId);

} 