package com.eden.room.mapper;

import com.eden.room.domain.RoomExtendInfo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 房源拓展信息数据访问层
 */
@Mapper
public interface RoomExtendInfoMapper {
    
    /**
     * 查询房源拓展信息列表
     *
     * @param extendInfo 房源拓展信息
     * @return 房源拓展信息列表
     */
    List<RoomExtendInfo> selectRoomExtendInfoList(RoomExtendInfo extendInfo);
    
    /**
     * 根据ID查询房源拓展信息
     *
     * @param id 拓展信息ID
     * @return 房源拓展信息
     */
    RoomExtendInfo selectRoomExtendInfoById(@Param("id") String id);
    
    /**
     * 根据房源ID查询拓展信息
     *
     * @param roomId 房源ID
     * @return 房源拓展信息
     */
    RoomExtendInfo selectRoomExtendInfoByRoomId(@Param("roomId") Long roomId);

    /**
     * 批量插入房源扩展信息
     *
     * @param extendInfos 房源扩展信息列表
     * @return 插入结果
     */
    int batchInsertExtendInfos(List<RoomExtendInfo> extendInfos);
    /**
     * 修改房源拓展信息
     *
     * @param extendInfo 房源拓展信息
     * @return 结果
     */
    int updateRoomExtendInfo(RoomExtendInfo extendInfo);
    
    /**
     * 删除房源拓展信息
     *
     * @param id 拓展信息ID
     * @return 结果
     */
    int deleteRoomExtendInfoById(@Param("id") String id);
    
    /**
     * 根据房源ID删除拓展信息
     *
     * @param roomId 房源ID
     * @return 结果
     */
    int deleteRoomExtendInfoByRoomId(@Param("roomId") Long roomId);

} 