package com.eden.room.mapper;

import java.util.List;
import java.util.Set;

import com.eden.room.domain.dto.RoomQueryDTO;
import org.apache.ibatis.annotations.Param;
import com.eden.room.domain.Room;
import org.apache.ibatis.annotations.Mapper;

/**
 * 房源数据访问层
 */
@Mapper
public interface RoomMapper {
    /**
     * 查询房源列表
     *
     * @param queryDTO 房源信息
     * @return 房源列表
     */
    List<Room> selectRoomList( RoomQueryDTO queryDTO);
    
    /**
     * 根据ID查询房源
     *
     * @param id 房源ID
     * @return 房源信息
     */
    Room selectRoomById(@Param("id") Long id);

    /**
     * 修改房源
     *
     * @param room 房源信息
     * @return 结果
     */
    int updateRoom(Room room);
    
    /**
     * 删除房源
     *
     * @param id 房源ID
     * @return 结果
     */
    int deleteRoomById(@Param("id") Long id);
    
    /**
     * 批量删除房源
     *
     * @param ids 房源ID数组
     * @return 结果
     */
    int deleteRoomByIds(@Param("ids") List<Long> ids);
    
    /**
     * 检查房号是否已存在
     *
     * @param roomNumber 房号
     * @param projectId 项目ID
     * @param buildingId 楼宇ID
     * @param floorId 楼层ID
     * @return 是否存在
     */
    boolean checkRoomNumberExist(@Param("roomNumber") String roomNumber, 
                               @Param("projectId") String projectId, 
                               @Param("buildingId") Long buildingId,
                               @Param("floorId") Long floorId);

    /**
     * 检查房间数字编号是否已存在
     *
     * @param roomDigitalNumber 房间数字编号
     * @param projectId 项目ID
     * @param buildingId 楼宇ID
     * @param floorId 楼层ID
     * @return 是否存在
     */
    boolean checkRoomDigitalNumberExist(@Param("roomDigitalNumber") String roomDigitalNumber,
                                      @Param("projectId") String projectId,
                                      @Param("buildingId") Long buildingId,
                                      @Param("floorId") Long floorId);


    /**
     * 批量插入房源信息
     *
     * @param rooms 房源信息列表
     * @return 插入结果
     */
    int batchInsertRooms(@Param("list")  List<Room> rooms);

    /**
     * 获取指定项目下已存在的房间号
     * 
     * @param projectId 项目ID
     * @param roomNumbers 待检查的房间号列表
     * @return 已存在的房间号集合
     */
    Set<String> getExistingRoomNumbers(@Param("projectId") String projectId, @Param("roomNumbers") Set<String> roomNumbers);
} 