package com.eden.room.utils;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

/**
 * 枚举转换工具类
 */
public class EnumConverter {
    
    /**
     * 转换对象中的枚举字段
     */
    public static void convert(Object obj) {
        if (obj == null) {
            return;
        }

        Class<?> clazz = obj.getClass();
        Field[] fields = clazz.getDeclaredFields();
        
        for (Field field : fields) {
            EnumConvert annotation = field.getAnnotation(EnumConvert.class);
            if (annotation != null) {
                try {
                    convertField(obj, field, annotation);
                } catch (Exception e) {
                    throw new RuntimeException("枚举转换失败: " + field.getName(), e);
                }
            }
        }
    }

    /**
     * 转换字段值
     */
    private static void convertField(Object obj, Field field, EnumConvert annotation) throws Exception {
        field.setAccessible(true);
        Object value = field.get(obj);
        
        if (value != null) {
            Class<? extends Enum<?>> enumClass = annotation.value();
            // 获取getValue静态方法
            Method getValueMethod = enumClass.getMethod(annotation.method(), String.class);
            // 直接调用getValue方法获取转换后的值
            Object convertedValue = getValueMethod.invoke(null, value.toString());
            field.set(obj, convertedValue);
        }
    }
} 