package com.eden.room.utils;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import java.lang.reflect.Method;

/**
 * 枚举校验器
 */
public class EnumValidator implements ConstraintValidator<EnumValid, String> {

    private Class<? extends Enum<?>> enumClass;
    private String methodName;

    @Override
    public void initialize(EnumValid constraintAnnotation) {
        this.enumClass = constraintAnnotation.value();
        this.methodName = constraintAnnotation.method();
    }

    @Override
    public boolean isValid(String value, ConstraintValidatorContext context) {
        if (value == null || value.isEmpty()) {
            return true;
        }

        try {
            Method method = enumClass.getMethod(methodName, String.class);
            return (boolean) method.invoke(null, value);
        } catch (Exception e) {
            return false;
        }
    }
} 