package com.eden.room.utils.excel;

import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.alibaba.excel.write.metadata.style.WriteCellStyle;
import com.alibaba.excel.write.metadata.style.WriteFont;
import com.alibaba.excel.write.style.HorizontalCellStyleStrategy;
import org.apache.poi.ss.usermodel.*;
import org.springframework.validation.Validator;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * Excel导入监听器
 * @param <T> 导入数据类型
 */
public abstract class ExcelImportListener<T> extends AnalysisEventListener<T> {

    protected final List<T> dataList = new ArrayList<>();
    protected final Map<Integer, String> errorMap = new ConcurrentHashMap<>();
    protected  Boolean successFlag = true;
    protected final Validator validator;

    public ExcelImportListener(Validator validator) {
        this.validator = validator;
    }

    @Override
    public void invoke(T data, AnalysisContext context) {

    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        // 处理剩余数据
        if (!dataList.isEmpty()) {
            batchProcess();
        }
    }

    /**
     * 批量处理数据
     */
    protected abstract void batchProcess();

    /**
     * 获取错误信息
     */
    public Map<Integer, String> getErrorMap() {
        return errorMap;
    }

    public Boolean getSuccessFlag() {
        return successFlag;
    }


    public abstract  List<T> getDataList();
}